construct_arguments

Function construct_arguments 

pub fn construct_arguments(
    kb: &KnowledgeBase,
    rules: &[Rule],
) -> Result<Vec<Argument>, Error>
Build all possible arguments from a knowledge base and rule set by forward chaining to a fixed point.

Returns crate::Error::Aspic if the rule set contains a dependency cycle (which would prevent termination).