pub enum AttackKind {
Undermine,
Undercut,
Rebut,
}Expand description
The kind of attack.
Variants
Undermine
Attacks an ordinary premise used by the target argument.
Undercut
Attacks a defeasible rule used by the target argument.
Rebut
Attacks the target’s conclusion (and the target ends in a defeasible rule).